3D beamforming
==============
This example demonstrates a 3D beamforming setup with simulated point sources. 

Download: :download:`example_3D_beamforming.py <../../../examples/example_3D_beamforming.py>`

The script produces the figure:

.. figure:: example_3D_beamforming_1.png
    :align: center
    :width: 100%
    :figwidth: 50%

    Views (summed sound maps) along x,y, and z axis for a setup with 3 different point sources. Evaluation done with the CLEAN-SC algorithm.

.. literalinclude:: ../../../examples/example_3D_beamforming.py
